@@ -28,26 +28,42 @@
  *
  * Author: Miguel de Icaza
  */
+
+#define _XOPEN_SOURCE
+
 #include <config.h>
-#include <libgnome/gnome-macros.h>
 
 #include <time.h>
 #include <string.h>
 #include <stdlib.h> /* atoi */
 #include <stdio.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
-
-#include "gnome-dateedit.h"
+#include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-i18n.h>
 
 #include "gnometypebuiltins.h"
 
 #include "libgnomeui-access.h"
 
+#include "gnome-dateedit.h"
+
+#ifdef G_OS_WIN32
+/* The use of strtok_r() in this file doesn't require us to use a real
+ * strtok_r(). (Which doesn't exist in Microsoft's C library.)
+ * Microsoft's strtok() uses a thread-local buffer, not a
+ * caller-allocated buffer like strtok_r(). But this is fine for the
+ * way it gets used here. To avoid gcc warnings about unused
+ * variables, use the third argument to store the return value from
+ * strtok().
+ */
+#define strtok_r(s, delim, ptrptr) (*(ptrptr) = strtok (s, delim))
+#endif
+
 struct _GnomeDateEditPrivate {
 	GtkWidget *date_entry;
 	GtkWidget *date_button;
@@ -693,11 +709,21 @@ gnome_date_edit_set_time (GnomeDateEdit *gde, time_t the_time)
 
 	/* Set the time */
 	if (gde->_priv->flags & GNOME_DATE_EDIT_24_HR) {
-		if (strftime (buffer, sizeof (buffer), "%H:%M", mytm) == 0)
-			strcpy (buffer, "???");
+		if (gde->_priv->flags & GNOME_DATE_EDIT_DISPLAY_SECONDS) {
+			if (strftime (buffer, sizeof (buffer), "%H:%M:%S", mytm) == 0)
+    				strcpy (buffer, "???");
+        	} else {
+			if (strftime (buffer, sizeof (buffer), "%H:%M", mytm) == 0)
+    				strcpy (buffer, "???");
+        	}
 	} else {
-		if (strftime (buffer, sizeof (buffer), "%I:%M %p", mytm) == 0)
-			strcpy (buffer, "???");
+		if (gde->_priv->flags & GNOME_DATE_EDIT_DISPLAY_SECONDS) {
+			if (strftime (buffer, sizeof (buffer), "%I:%M:%S %p", mytm) == 0)
+				strcpy (buffer, "???");
+        	} else {
+			if (strftime (buffer, sizeof (buffer), "%I:%M %p", mytm) == 0)
+				strcpy (buffer, "???");
+        	}
 	}
 	buffer[sizeof(buffer)-1] = '\0';
 
