@@ -21,6 +21,8 @@
 #ifndef GNOME_WINDOW_ICON_H
 #define GNOME_WINDOW_ICON_H
 
+#ifndef GNOME_DISABLE_DEPRECATED
+
 #include <gtk/gtkwindow.h>
 
 G_BEGIN_DECLS
@@ -39,4 +41,7 @@ void gnome_window_icon_init (void);
 
 G_END_DECLS
 
+#endif /* GNOME_DISABLE_DEPRECATED */
+
 #endif /* GNOME_WINDOW_ICON_H */
+
